# laplace-blivedm

Fork of [blivedm](https://github.com/xfgryujk/blivedm) with additional events support

## Install

```bash
pip install laplace-blivedm
```

## Usage

See `sample.py`

## License

MIT
